package Module::Compile::TT;

use strict;
use warnings;

1;

=pod

=head1 NAME

Module::Compile::TT - Preprocess Perl code with Template Toolkit and Module::Compile.

=head1 SYNOPSIS

	use tt;

	...

=head1 DESCRIPTION

See L<tt> for the actual documentation. This is mostly just a placeholder for
declaring prettier dependancies.

=cut


